{% if cl.search_fields %}
<div id="toolbar"><form id="changelist-search" action="" method="get">
<div><!-- DIV needed for valid HTML -->
<label for="searchbar"><img src="{{ admin_media_prefix }}img/admin/icon_searchbox.png" alt="Search" /></label>
<input type="text" size="40" name="{{ search_var }}" value="{{ cl.query }}" id="searchbar" />
<input type="submit" value="{{ _('Search') }}" />
{% if show_result_count %}
    <span class="small quiet">{% trans count=cl.result_count %}{{ count }} result{% pluralize %}{{ count }} results{% endtrans %} (<a href="?{% if cl.is_popup %}pop=1{% endif %}">{% trans full_result_count=cl.full_result_count %}{{ full_result_count }} total{% endtrans %}</a>)</span>
{% endif %}
{% for pair in cl.params.items() %}
    {% if pair.0 != search_var %}<input type="hidden" name="{{ pair.0 }}" value="{{ pair.1 }}"/>{% endif %}
{% endfor %}
</div>
</form></div>
<script type="text/javascript">document.getElementById("searchbar").focus();</script>
{% endif %}
