<div class="djDebugPanelTitle">
	<a class="djDebugClose djDebugBack" href="">{{ _("Back") }}</a>
	<h3>{{ _('Template Source') }}: <code>{{ template_name }}</code></h3>
</div>
<div class="djDebugPanelContent">
	<div class="scroll">
		{% if not source.pygmentized %}
			<code>{{ source }}</code>
		{% else %}
			{{ source }}
		{% endif %}
	</div>
</div>