{% extends "admin/base_site.html" %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="/">{{ _("Home") }}</a> &rsaquo; {{ _("Server error") }}</div>{% endblock %}

{% block title %}{{ _('Server error (500)') }}{% endblock %}

{% block content %}
<h1>{{ _('Server Error <em>(500)</em>') }}</h1>
<p>{{ _("There's been an error. It's been reported to the site administrators via e-mail and should be fixed shortly. Thanks for your patience.") }}</p>

{% endblock %}