<table>
	<thead>
		<tr>
			<th>{{ _("Signal") }}</th>
			<th>{{ _('Providing Args') }}</th>
			<th>{{ _('Receivers') }}</th>
		</tr>
	</thead>
	<tbody>
		{% for name, signal, receivers in signals %}
			<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
				<td>{{ name|escape }}</td>
				<td>{{ signal.providing_args|join(", ") }}</td>
				<td>{{ receivers|join(", ") }}</td>
			</tr>
		{% endfor %}
	</tbody>
</table>