<style type="text/css">@media print { #djDebug {display:none;}}</style>
<script type="text/javascript">
// <![CDATA[
var DEBUG_TOOLBAR_MEDIA_URL = "{{ DEBUG_TOOLBAR_MEDIA_URL }}";
// ]]>
</script>
<script type="text/javascript" src="{{ DEBUG_TOOLBAR_MEDIA_URL }}js/toolbar.min.js"></script>
<div id="djDebug" style="display:none;">
	<div style="display:none;" id="djDebugToolbar">
		<ul id="djDebugPanelList">
			{% if panels %}
			<li><a id="djHideToolBarButton" href="#" title="{{ _("Hide Toolbar") }}">{{ _("Hide") }} &raquo;</a></li>
			{% else %}
			<li id="djDebugButton">DEBUG</li>
			{% endif %}
			{% for panel in panels %}
				<li>
					{% if panel.has_content %}
						<a href="{{ panel.url()|default("#") }}" title="{{ panel.title() }}" class="{{ panel.dom_id() }}">
					{% else %}
					    <div class="contentless">
					{% endif %}
					{{ panel.nav_title() }}
					{% set subtitle=panel.nav_subtitle %}
					{% if subtitle %}<br /><small>{{ subtitle() }}</small>{% endif %}
					{% if panel.has_content %}
						</a>
					{% else %}
					    </div>
					{% endif %}
				</li>
			{% endfor %}
		</ul>
	</div>
	<div style="display:none;" id="djDebugToolbarHandle">
		<a title="{{ _("Show Toolbar") }}" id="djShowToolBarButton" href="#">&laquo;</a>
	</div>
	{% for panel in panels %}
		{% if panel.has_content %}
			<div id="{{ panel.dom_id() }}" class="panelContent">
				<div class="djDebugPanelTitle">
					<a href="" class="djDebugClose">{{ _("Close") }}</a>
					<h3>{{ panel.title()|escape }}</h3>
				</div>
				<div class="djDebugPanelContent">
				    <div class="scroll">
				        {{ panel.content()|escape }}
				    </div>
				</div>
			</div>
		{% endif %}
	{% endfor %}
	<div id="djDebugWindow" class="panelContent"></div>
</div>
