<h4>{{ _('View information') }}</h4>
<table>
	<thead>
		<tr>
			<th>{{ _('View Function') }}</th>
			<th>{{ _('args') }}</th>
			<th>{{ _('kwargs') }}</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>{{ view_func }}</td>
			<td>{{ view_args|default("None") }}</td>
			<td>
			{% if view_kwargs.items %}
				{% for k, v in view_kwargs.items() %}
					{{ k }}={{ v }}{% if not loop.last %}, {% endif %}
				{% endfor %}
			{% else %}
				None
			{% endif %}
			</td>
		</tr>
	</tbody>
</table>

<h4>{{ _('COOKIES Variables') }}</h4>
{% if cookies %}
	<table>
		<colgroup>
			<col style="width:20%"/>
			<col/>
		</colgroup>
		<thead>
			<tr>
				<th>{{ _("Variable") }}</th>
				<th>{{ _("Value") }}</th>
			</tr>
		</thead>
		<tbody>
			{% for key, value in cookies %}
				<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
					<td>{{ key|escape }}</td>
					<td>{{ value|escape }}</td>
				</tr>
			{% endfor %}
		</tbody>
	</table>
{% else %}
	<p>{{ _("No COOKIE data") }}</p>
{% endif %}

<h4>{{ _('SESSION Variables') }}</h4>
{% if session %}
	<table>
		<colgroup>
			<col style="width:20%"/>
			<col/>
		</colgroup>
		<thead>
			<tr>
				<th>{{ _("Variable") }}</th>
				<th>{{ _("Value") }}</th>
			</tr>
		</thead>
		<tbody>
			{% for key, value in session %}
				<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
					<td>{{ key|escape }}</td>
					<td>{{ value|escape }}</td>
				</tr>
			{% endfor %}
		</tbody>
	</table>
{% else %}
	<p>{{ _("No SESSION data") }}</p>
{% endif %}

<h4>{{ _('GET Variables') }}</h4>
{% if get %}
	<table>
		<thead>
			<tr>
				<th>{{ _("Variable") }}</th>
				<th>{{ _("Value") }}</th>
			</tr>
		</thead>
		<tbody>
			{% for key, value in get %}
				<tr class="{{ loop.cycle('djDebugOdd','djDebugEven') }}">
					<td>{{ key|escape }}</td>
					<td>{{ value|join(", ")|escape }}</td>
				</tr>
			{% endfor %}
		</tbody>
	</table>
{% else %}
	<p>{{ _("No GET data") }}</p>
{% endif %}

<h4>{{ _('POST Variables') }}</h4>
{% if post %}
	<table>
		<thead>
			<tr>
				<th>{{ _("Variable") }}</th>
				<th>{{ _("Value") }}</th>
			</tr>
		</thead>
		<tbody>
			{% for key, value in post %}
				<tr class="{{ loop.cycle('row1','row2') }}">
					<td>{{ key|escape }}</td>
					<td>{{ value|join(", ")|escape }}</td>
				</tr>
			{% endfor %}
		</tbody>
	</table>
{% else %}
	<p>{{ _("No POST data") }}</p>
{% endif %}
