{% extends "admin/base_site.html" %}

{% block extrastyle %}{{ super() }}<link rel="stylesheet" type="text/css" href="{{ admin_media_prefix }}css/dashboard.css" />{% endblock %}

{% block coltype %}colMS{% endblock %}

{% block bodyclass %}dashboard{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
<div id="content-main">

{% if app_list %}
    {% for app in app_list %}
        <div class="module">
        <table summary="{% trans name=app.name %}Models available in the {{ name }} application.{% endtrans %}">
        <caption><a href="{{ app.app_url }}" class="section">{% trans name=app.name %}{{ name }}{% endtrans %}</a></caption>
        {% for model in app.models %}
            <tr>
            {% if model.perms.change %}
                <th scope="row"><a href="{{ model.admin_url }}">{{ model.name }}</a></th>
            {% else %}
                <th scope="row">{{ model.name }}</th>
            {% endif %}

            {% if model.perms.add %}
                <td><a href="{{ model.admin_url }}add/" class="addlink">{{ _('Add') }}</a></td>
            {% else %}
                <td>&nbsp;</td>
            {% endif %}

            {% if model.perms.change %}
                <td><a href="{{ model.admin_url }}" class="changelink">{{ _('Change') }}</a></td>
            {% else %}
                <td>&nbsp;</td>
            {% endif %}
            </tr>
        {% endfor %}
        </table>
        </div>
    {% endfor %}
{% else %}
    <p>{{ _("You don't have permission to edit anything.") }}</p>
{% endif %}
</div>
{% endblock %}

{% block sidebar %}
<div id="content-related">
    <div class="module" id="recent-actions-module">
        <h2>{{ _('Recent Actions') }}</h2>
        <h3>{{ _('My Actions') }}</h3>
        {% load 'log' %}
            {% set admin_log=get_admin_log(10,user=user) %}
            
            {% if not admin_log %}
            <p>{{ _('None available') }}</p>
            {% else %}
            <ul class="actionlist">
            {% for entry in admin_log %}
            <li class="{% if entry.is_addition() %}addlink{% endif %}{% if entry.is_change() %}changelink{% endif %}{% if entry.is_deletion() %}deletelink{% endif %}">
                {% if entry.is_deletion() or not entry.get_admin_url() %}
                    {{ entry.object_repr }}
                {% else %}
                    <a href="{{ entry.get_admin_url() }}">{{ entry.object_repr }}</a>
                {% endif %}
                <br/>
                {% if entry.content_type %}
                    <span class="mini quiet">{{ _(entry.content_type.name)|capitalize }}</span>
                {% else %}
                    <span class="mini quiet">{{ _('Unknown content') }}</span>
                {% endif %}
            </li>
            {% endfor %}
            </ul>
            {% endif %}
    </div>
</div>
{% endblock %}