<table>
	<colgroup>
		<col width="12%"/>
		<col width="12%"/>
		<col width="12%"/>
		<col width="12%"/>
		<col width="12%"/>
		<col width="12%"/>
		<col width="12%"/>
		<col width="12%"/>
	</colgroup>
	<tr>
		<th>{{ _("Total Calls") }}</th>
		<td>{{ cache_calls }}</td>
		<th>{{ _("Total Time") }}</th>
		<td>{{ cache_time }}ms</td>
		<th>{{ _("Hits") }}</th>
		<td>{{ cache.hits }}</td>
		<th>{{ _("Misses") }}</th>
		<td>{{ cache.misses }}</td>
	</tr>
	<tr>
		<th>gets</th>
		<td>{{ cache.gets }}</td>
		<th>sets</th>
		<td>{{ cache.sets }}</td>
		<th>deletes</th>
		<td>{{ cache.deletes }}</td>
		<th>get_many</th>
		<td>{{ cache.get_many }}</td>
	</tr>
</table>
{% if cache.calls %}
<h3>{{ _("Breakdown") }}</h3>
<table>
	<thead>
		<tr>
			<th>{{ _("Time") }}&nbsp;(ms)</th>
			<th>{{ _("Type") }}</th>
			<th>{{ _("Parameters") }}</th>
			<th>{{ _("Function") }}</th>
		</tr>
	</thead>
	<tbody>
		{% for query in cache.calls() %}
			<tr class="{{ loop.cycle('row1','row2') }}">
				<td>{{ query.0|floatformat("4") }}</td>
				<td>{{ query.1|escape }}</td>
				<td>{{ query.2|escape }}</td>
				<td><acronym title="{{ query.3.0 }}:{{ query.3.1 }}">{{ query.3.2|escape }}</acronym>: {{ query.3.3.0|escape }}</td>
			</tr>
		{% endfor %}
	</tbody>
</table>
{% endif %}