{% autoescape off %}
{% trans %}You're receiving this e-mail because you requested a password reset for your user account at {{ site_name }}.{% endtrans %}

{{ _("Please go to the following page and choose a new password:") }}
{% block reset_link %}
{{ protocol }}://{{ domain }}{{ url('django.contrib.auth.views.password_reset_confirm',uidb36=uid,token=token) }}
{% endblock %}
{{ _("Your username, in case you've forgotten:") }} {{ user.username }}

{{ _("Thanks for using our site!") }}

{% trans %}The {{ site_name }} team{% endtrans %}

{% endautoescape %}
