{% extends "admin/base_site.html" %}

{% block breadcrumbs %}
<div class="breadcrumbs">
     <a href="../../">{{ _("Home") }}</a> &rsaquo;
     <a href="../">{{ app_label|capitalize }}</a> &rsaquo;
     <a href="./">{{ opts.verbose_name_plural|capitalize }}</a> &rsaquo;
     {{ _('Delete multiple objects') }}
</div>
{% endblock %}

{% block content %}
{% if perms_lacking or protected %}
    {% if perms_lacking %}
        <p>{% trans %}Deleting the selected {{ objects_name }} would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endtrans %}</p>
        <ul>
        {% for obj in perms_lacking %}
            <li>{{ obj }}</li>
        {% endfor %}
        </ul>
    {% endif %}
    {% if protected %}
        <p>{% trans %}Deleting the selected {{ objects_name }} would require deleting the following protected related objects:{% endtrans %}</p>
        <ul>
        {% for obj in protected %}
            <li>{{ obj }}</li>
        {% endfor %}
        </ul>
    {% endif %}
{% else %}
    <p>{% trans %}Are you sure you want to delete the selected {{ objects_name }}? All of the following objects and their related items will be deleted:{% endtrans %}</p>
    {% for deletable_object in deletable_objects %}
        <ul>{{ deletable_object|unordered_list }}</ul>
    {% endfor %}
    <form action="" method="post">{% csrf_token %}
    <div>
    {% for obj in queryset %}
    <input type="hidden" name="{{ action_checkbox_name }}" value="{{ obj.pk }}" />
    {% endfor %}
    <input type="hidden" name="action" value="delete_selected" />
    <input type="hidden" name="post" value="yes" />
    <input type="submit" value="{{ _("Yes, I'm sure") }}" />
    </div>
    </form>
{% endif %}
{% endblock %}