{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../">{{ _('Home') }}</a> &rsaquo; {{ title }}</div>{% endblock %}

{% block content %}
<p>{{ _("Something's wrong with your database installation. Make sure the appropriate database tables have been created, and make sure the database is readable by the appropriate user.") }}</p>
{% endblock %}